==> dqops-1.5.0-py2.py3-none-any.whl: dqops/client/api/users/update_user.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.dqo_cloud_user_model import DqoCloudUserModel
from ...types import Response


def _get_kwargs(
    email: str,
    *,
    json_body: DqoCloudUserModel,
) -> Dict[str, Any]:

    pass

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": "api/users/{email}".format(
            email=email,
        ),
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.CREATED:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    email: str,
    *,
    client: AuthenticatedClient,
    json_body: DqoCloudUserModel,
) -> Response[Any]:
    """updateUser

     Updates a user in a multi-user account. The user's email cannot be changed.

    Args:
        email (str):
        json_body (DqoCloudUserModel): DQOps Cloud user model - identifies a user in a multi-user
            DQOps deployment.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        email=email,
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    email: str,
    *,
    client: AuthenticatedClient,
    json_body: DqoCloudUserModel,
) -> Response[Any]:
    """updateUser

     Updates a user in a multi-user account. The user's email cannot be changed.

    Args:
        email (str):
        json_body (DqoCloudUserModel): DQOps Cloud user model - identifies a user in a multi-user
            DQOps deployment.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        email=email,
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)

==> dqops-1.11.0-py2.py3-none-any.whl: dqops/client/api/users/update_user.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.dqo_user_roles_model import DqoUserRolesModel
from ...types import Response


def _get_kwargs(
    email: str,
    *,
    json_body: DqoUserRolesModel,
) -> Dict[str, Any]:

    pass

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": "api/users/{email}".format(
            email=email,
        ),
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.CREATED:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    email: str,
    *,
    client: AuthenticatedClient,
    json_body: DqoUserRolesModel,
) -> Response[Any]:
    """updateUser

     Updates a user in a multi-user account. The user's email cannot be changed.

    Args:
        email (str):
        json_body (DqoUserRolesModel): DQOps user model - identifies a user in a multi-user DQOps
            deployment and the user's roles.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        email=email,
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    email: str,
    *,
    client: AuthenticatedClient,
    json_body: DqoUserRolesModel,
) -> Response[Any]:
    """updateUser

     Updates a user in a multi-user account. The user's email cannot be changed.

    Args:
        email (str):
        json_body (DqoUserRolesModel): DQOps user model - identifies a user in a multi-user DQOps
            deployment and the user's roles.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        email=email,
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
